Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(661)

Unified Diff: chrome/browser/views/frame/opaque_non_client_view.h

Issue 18799: Make popups closer to pixel-perfect. The main problem is that the toolbar is... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/views/frame/browser_view.cc ('k') | chrome/browser/views/frame/opaque_non_client_view.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/views/frame/opaque_non_client_view.h
===================================================================
--- chrome/browser/views/frame/opaque_non_client_view.h (revision 8658)
+++ chrome/browser/views/frame/opaque_non_client_view.h (working copy)
@@ -95,10 +95,11 @@
// the window frame and the client edge.
int NonClientBottomBorderHeight() const;
- // For windows without a toolbar, restored mode also draws a client edge below
- // the titlebar which is considered part of the nonclient height. This
- // returns the height of any such edge.
- int ClientEdgeThicknessWithinNonClientHeight() const;
+ // For windows without a toolbar, a bottom border, and, in restored mode, a
+ // client edge are drawn at the bottom of the titlebar. When a toolbar is
+ // present, neither of these are drawn, as the toolbar itself will edge the
+ // titlebar area. This returns the height of any such edge.
+ int BottomEdgeThicknessWithinNonClientHeight() const;
// Calculates multiple values related to title layout. Returns the height of
// the entire titlebar including any connected client edge.
« no previous file with comments | « chrome/browser/views/frame/browser_view.cc ('k') | chrome/browser/views/frame/opaque_non_client_view.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698